Flask-User v0.6
===============

Modified for Docassemble.

.. attention::

    The documentation has moved to http://flask-user.readthedocs.io/en/v0.6


User Authentication and Management
----------------------------------

| So, you're writing a Flask web application and would like to authenticate your users.
| You start with a simple **Login** page, but soon enough you'll need to handle:

* **Registrations** and **Email Confirmations**
* **Change Usernames**, **Change Passwords**, and **Forgotten Passwords**

And wouldn't it be nice to also offer:

* **Added security**
* **Increased reliability**
* **Role-based Authorization**
* **Internationalization**
* **Support for multiple emails per user**

| Flask-User offers these features and more.


Customizable, yet Ready to use
------------------------------
* **Largely Configurable** -- By overriding configuration settings.
* **Almost fully Customizable** -- By overriding functions and properties.
* **Ready to use** -- Through sensible defaults.
* Supports **SQL Databases** and **MongoDB Databases**.
* **Event hooking** -- Through efficient signals.


Secure and Reliable
-------------------
* **Secure** -- Built on top of widely deployed Passlib, PyCrypto, ItsDangerous.
* **Reliable** -- Code coverage of over 90%
* **Available** -- Tested on Python 2.6, 2.7 and 3.3-3.6


Well documented
---------------
- `Flask-User v0.6 documentation <http://flask-user.readthedocs.io/en/v0.6/>`_
- `Flask-User v0.5 documentation <http://flask-user.readthedocs.io/en/v0.5/>`_


Comes with translations
-----------------------
Chinese, Dutch, English, Farsi, Finnish, French, German, Italian, Russian, Spanish, Swedish, and Turkish


Alternatives
------------
* `Flask-Login <https://flask-login.readthedocs.org/en/latest/>`_
* `Flask-Security <https://pythonhosted.org/Flask-Security/>`_

Authors
-------
| **Lead developer and Maintainer**
| Ling Thio -- ling.thio AT gmail DOT com
|
| **Contributors**
| `Many contributors <https://github.com/lingthio/Flask-User/graphs/contributors>`_
